pub enum DeterminantSign {
Negative,
Zero,
Positive,
}Expand description
The exact sign of a determinant.
Available with the exact Cargo feature.
This type makes the three possible outcomes explicit instead of exposing a raw integer that could contain values other than −1, 0, or +1.
Examples
use la_stack::prelude::*;
let sign = Matrix::<2>::identity().det_sign_exact();
assert_eq!(sign, DeterminantSign::Positive);
assert_eq!(sign.as_i8(), 1);Variants
Negative
The determinant is strictly negative.
Zero
The determinant is exactly zero.
Positive
The determinant is strictly positive.
Implementations