IntervalDeterminantSign

Enum IntervalDeterminantSign 

#[non_exhaustive]
pub enum IntervalDeterminantSign { Positive, Negative, Zero, Inconclusive, }
Sign evidence from an outward-rounded interval determinant.

Positive, Negative, and Zero are proofs about every determinant represented by the interval matrix. Inconclusive means the computed enclosure overlaps zero and must not be interpreted as exact singularity.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Positive

The determinant interval is strictly greater than zero.



Negative

The determinant interval is strictly less than zero.



Zero

The determinant interval is exactly [0, 0].



Inconclusive

The determinant interval contains zero and at least one nonzero value.