SingularityReason

Enum SingularityReason 

#[non_exhaustive]
pub enum SingularityReason { Exact,
#[non_exhaustive]
Numerical { factorization: FactorizationKind, pivot_magnitude: f64, tolerance: f64, }, }
Mathematical or numerical reason a matrix was classified as singular.

Examples

use la_stack::prelude::*;

match LaError::singular_numerical(1, FactorizationKind::Lu, 0.0, 1e-12) {
    LaError::Singular {
        reason: SingularityReason::Numerical { factorization, .. }, ..
    } => assert_eq!(factorization, FactorizationKind::Lu),
    _ => unreachable!("constructor preserves the singularity reason"),
}

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Exact

The algorithm proved that the pivot is exactly zero.



#[non_exhaustive]
Numerical

A finite pivot was rejected by the factorization tolerance.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
factorization: FactorizationKind

Factorization applying the tolerance policy.

pivot_magnitude: f64

Absolute magnitude of the rejected pivot.

tolerance: f64

Tolerance against which the magnitude was compared.