UnrepresentableReason

Enum UnrepresentableReason 

#[non_exhaustive]
pub enum UnrepresentableReason { RequiresRounding, NotFinite, }
Reason an exact result cannot satisfy an exact-to-f64 conversion contract.

RequiresRounding is recoverable when the caller is willing to opt into a rounded exact-to-f64 API. NotFinite means even the rounded result would not be a finite f64.

Examples

use la_stack::prelude::*;

let err = LaError::unrepresentable(None, UnrepresentableReason::RequiresRounding);
assert!(err.requires_rounding());

let err = LaError::unrepresentable(None, UnrepresentableReason::NotFinite);
assert_eq!(
    err.unrepresentable_reason(),
    Some(UnrepresentableReason::NotFinite)
);

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


RequiresRounding

A finite f64 exists only after rounding, but the requested conversion requires an exact binary64 representation.



NotFinite

The exact value would convert to NaN or infinity rather than a finite f64.